==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/rbac/v1alpha1/ServiceRoleBindingSpecFluent.java <==
package me.snowdrop.istio.api.rbac.v1alpha1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ServiceRoleBindingSpecFluent<A extends ServiceRoleBindingSpecFluent<A>> extends Fluent<A>{


    public EnforcementMode getMode();
    public A withMode(EnforcementMode mode);
    public Boolean hasMode();
    
/**
 * This method has been deprecated, please use method buildRoleRef instead.
 * @return The buildable object.
 */
@Deprecated public RoleRef getRoleRef();
    public RoleRef buildRoleRef();
    public A withRoleRef(RoleRef roleRef);
    public Boolean hasRoleRef();
    public A withNewRoleRef(String kind,String name);
    public ServiceRoleBindingSpecFluent.RoleRefNested<A> withNewRoleRef();
    public ServiceRoleBindingSpecFluent.RoleRefNested<A> withNewRoleRefLike(RoleRef item);
    public ServiceRoleBindingSpecFluent.RoleRefNested<A> editRoleRef();
    public ServiceRoleBindingSpecFluent.RoleRefNested<A> editOrNewRoleRef();
    public ServiceRoleBindingSpecFluent.RoleRefNested<A> editOrNewRoleRefLike(RoleRef item);
    public A addToSubjects(int index,Subject item);
    public A setToSubjects(int index,Subject item);
    public A addToSubjects(Subject... items);
    public A addAllToSubjects(Collection<Subject> items);
    public A removeFromSubjects(Subject... items);
    public A removeAllFromSubjects(Collection<Subject> items);
    
/**
 * This method has been deprecated, please use method buildSubjects instead.
 * @return The buildable object.
 */
@Deprecated public List<Subject> getSubjects();
    public List<Subject> buildSubjects();
    public Subject buildSubject(int index);
    public Subject buildFirstSubject();
    public Subject buildLastSubject();
    public Subject buildMatchingSubject(io.fabric8.kubernetes.api.builder.Predicate<SubjectBuilder> predicate);
    public A withSubjects(List<Subject> subjects);
    public A withSubjects(Subject... subjects);
    public Boolean hasSubjects();
    public ServiceRoleBindingSpecFluent.SubjectsNested<A> addNewSubject();
    public ServiceRoleBindingSpecFluent.SubjectsNested<A> addNewSubjectLike(Subject item);
    public ServiceRoleBindingSpecFluent.SubjectsNested<A> setNewSubjectLike(int index,Subject item);
    public ServiceRoleBindingSpecFluent.SubjectsNested<A> editSubject(int index);
    public ServiceRoleBindingSpecFluent.SubjectsNested<A> editFirstSubject();
    public ServiceRoleBindingSpecFluent.SubjectsNested<A> editLastSubject();
    public ServiceRoleBindingSpecFluent.SubjectsNested<A> editMatchingSubject(io.fabric8.kubernetes.api.builder.Predicate<SubjectBuilder> predicate);

    public interface RoleRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RoleRefFluent<ServiceRoleBindingSpecFluent.RoleRefNested<N>>{

        
    public N and();    public N endRoleRef();
}
    public interface SubjectsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SubjectFluent<ServiceRoleBindingSpecFluent.SubjectsNested<N>>{

        
    public N and();    public N endSubject();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/rbac/v1alpha1/ServiceRoleBindingSpecFluent.java <==
package me.snowdrop.istio.api.rbac.v1alpha1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ServiceRoleBindingSpecFluent<A extends ServiceRoleBindingSpecFluent<A>> extends Fluent<A>{


    public EnforcementMode getMode();
    public A withMode(EnforcementMode mode);
    public Boolean hasMode();
    
/**
 * This method has been deprecated, please use method buildRoleRef instead.
 * @return The buildable object.
 */
@Deprecated public RoleRef getRoleRef();
    public RoleRef buildRoleRef();
    public A withRoleRef(RoleRef roleRef);
    public Boolean hasRoleRef();
    public A withNewRoleRef(String kind,String name);
    public ServiceRoleBindingSpecFluent.RoleRefNested<A> withNewRoleRef();
    public ServiceRoleBindingSpecFluent.RoleRefNested<A> withNewRoleRefLike(RoleRef item);
    public ServiceRoleBindingSpecFluent.RoleRefNested<A> editRoleRef();
    public ServiceRoleBindingSpecFluent.RoleRefNested<A> editOrNewRoleRef();
    public ServiceRoleBindingSpecFluent.RoleRefNested<A> editOrNewRoleRefLike(RoleRef item);
    public A addToSubjects(int index,Subject item);
    public A setToSubjects(int index,Subject item);
    public A addToSubjects(Subject... items);
    public A addAllToSubjects(Collection<Subject> items);
    public A removeFromSubjects(Subject... items);
    public A removeAllFromSubjects(Collection<Subject> items);
    public A removeMatchingFromSubjects(io.fabric8.kubernetes.api.builder.Predicate<SubjectBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildSubjects instead.
 * @return The buildable object.
 */
@Deprecated public List<Subject> getSubjects();
    public List<Subject> buildSubjects();
    public Subject buildSubject(int index);
    public Subject buildFirstSubject();
    public Subject buildLastSubject();
    public Subject buildMatchingSubject(io.fabric8.kubernetes.api.builder.Predicate<SubjectBuilder> predicate);
    public Boolean hasMatchingSubject(io.fabric8.kubernetes.api.builder.Predicate<SubjectBuilder> predicate);
    public A withSubjects(List<Subject> subjects);
    public A withSubjects(Subject... subjects);
    public Boolean hasSubjects();
    public ServiceRoleBindingSpecFluent.SubjectsNested<A> addNewSubject();
    public ServiceRoleBindingSpecFluent.SubjectsNested<A> addNewSubjectLike(Subject item);
    public ServiceRoleBindingSpecFluent.SubjectsNested<A> setNewSubjectLike(int index,Subject item);
    public ServiceRoleBindingSpecFluent.SubjectsNested<A> editSubject(int index);
    public ServiceRoleBindingSpecFluent.SubjectsNested<A> editFirstSubject();
    public ServiceRoleBindingSpecFluent.SubjectsNested<A> editLastSubject();
    public ServiceRoleBindingSpecFluent.SubjectsNested<A> editMatchingSubject(io.fabric8.kubernetes.api.builder.Predicate<SubjectBuilder> predicate);

    public interface RoleRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RoleRefFluent<ServiceRoleBindingSpecFluent.RoleRefNested<N>>{

        
    public N and();    public N endRoleRef();
}
    public interface SubjectsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SubjectFluent<ServiceRoleBindingSpecFluent.SubjectsNested<N>>{

        
    public N and();    public N endSubject();
}


}
